function [classes, cert] = nneigh_class_2d(x, xlearn, labels)
//-----------------------------------------------------------------------  
// function [classes, cert] = nneigh_class_2d(x, xlearn, labels)
//
// implementation of nearest neighbour classification 
// of two-dimensional vectors based on learning set. 
//
// input:    x            2 times n - matrix consisting of n points to be 
//                        classified
//           xlearn       2 times m - matrix consisting of learning 
//                        points
//           labels       m-vector of integer class-labels.             
//
// output:   classes      n-vector of estimated class memberships, integers 
//           cert         n-vector of "certainty" measures for the 
//                        classifications, in this case e^(-dmin^2)
//                        (only heuristic, no theoretic foundation for
//                        "certainty")
//
//-----------------------------------------------------------------------  
//   $RCSfile: nneigh_class_2d.sci,v $
//  $Revision: 1.1 $
//      $Date: 2002/09/10 15:15:36 $
//  Copyright: IIF-LMB $Author: poluru $
//
//-----------------------------------------------------------------------
//  $Log: nneigh_class_2d.sci,v $
//  Revision 1.1  2002/09/10 15:15:36  poluru
//  "macros" directory structure is created
//
//-----------------------------------------------------------------------

  [out,in] = argn(0);

  if in~=3,
    
    if in~=1,
      error('wrong number of input arguments.');
    end;
    
    //if the classification data is not porvided by the user
    // DATA is the absolute path to the data directory
    global DATA;
    exec(DATA+'data.sci');
    xlearn=V;
    labels=l;
  end;
  
  ntest = size(x,2);
  nlearn = size(xlearn,2);
  
  // generate ntest x nlearn coordinate matrices by 'repetition' 
  testx1 = x(1,:)' * ones(1,nlearn);   
  testx2 = x(2,:)' * ones(1,nlearn);   
  learnx1 = (xlearn(1,:)' * ones(1,ntest))';   
  learnx2 = (xlearn(2,:)' * ones(1,ntest))';   
  
  // generate squared-distance matrix for all learn/test-pairs
  distsqr = (testx1-learnx1).^2 + (testx2-learnx2).^2;
  
  // find minima and indices  
  [distsqrmin, indmin] = min(distsqr,'c');
  classes = labels(indmin);
  cert = exp(-distsqrmin)';
  
endfunction










