function visclass_2d(classifier, varargin)
//-----------------------------------------------------------------------  
//function visclass_2d(classifier, varargin)
//
// visualization of classification regions in 2 dimensions, default range
// is x,y = -3,...,+3, colorsfor classes: red, blue, green, yellow, purple.
//
// input:    classifier   function, which will be called by 
//                        [classes, cert] = classifier(x, varargin)
//                        and is assumed to classify the columnwise 
//                        points in x, returning vectors of class-numbers 
//                        and classification certainties in cert.
//           varargin     variable parameter list, which is simply 
//                        forwarded to the function 'classifier'.
// output:   none
//
//-----------------------------------------------------------------------  
//   $RCSfile: visclass_2d.sci,v $
//  $Revision: 1.2 $
//      $Date: 2002/09/10 18:17:47 $
//  Copyright: IIF-LMB $Author: poluru $
//
//-----------------------------------------------------------------------
//  $Log: 
//-----------------------------------------------------------------------

 
  [out,in] = argn(0);
  
  if in==0,
    classifier = dumb_class_2d;
    varargin = list();
  end
    
  // some default colors
  //colm = [0, 0, 0; 0, 0, 0 ; 0, 0, 0; 0,0,0; 0, 0, 0];
  colm = [1, 0, 0; 0, 0, 1 ; 0, 1, 0; 1,1,0; 1, 0, 1];
  xset("colormap",colm);
  
  x = -3:0.2:3;
  y = x;
  
  pointsx = x' * ones(1,length(x));  
  pointsy = (y' * ones(1,length(y)))';  
  
  [dummy, cert]= classifier([pointsx(:)' ; pointsy(:)'],varargin(:));
  
  certmat = matrix(cert,length(x),length(y));
    
  // surface graph of certainties with classdependent colors
  // midpoints of facets classified again   
  [xx,yy,zz] = genfac3d(x,y,certmat);
  xm = sum(xx,'r')/4;
  ym = sum(yy,'r')/4;
  
  [cl, dummy]= classifier([xm ; ym],varargin(:));

  plot3d(xx,yy,list(zz,cl));
  
endfunction;




